@@ -370,6 +370,54 @@ class EFAwsResolver(object):
         oldest = vpce
     return oldest["VpcEndpointId"]
 
+  def ec2_vpc_endpoint_dns_name(self, lookup, default=None):
+    """
+    Args:
+      lookup: the name of the VPC endpoint to look up (in tags)
+      default: the optional value to return if lookup failed; returns None if not set
+    Returns:
+      The first DNS Name of the VPC Endpoint found with a label matching 'lookup' or default/None if no match found
+    """
+    vpc_endpoints = EFAwsResolver.__CLIENTS["ec2"].describe_vpc_endpoints(Filters=[{
+      "Name": "tag:Name",
+      "Values": [lookup]
+    }])
+    if len(vpc_endpoints.get("VpcEndpoints")) > 0:
+      if len(vpc_endpoints["VpcEndpoints"][0]["DnsEntries"]) < 1:
+        return default
+      return vpc_endpoints["VpcEndpoints"][0]["DnsEntries"][0]["DnsName"]
+    else:
+      return default
+
+  def ec2_vpc_endpoint_dns_name_by_vpc_service(self, lookup, default=None):
+    """
+    Args:
+      lookup: a forward-slash-delimited string of [vpc-name, service-name] "vpc-name/service-name"
+      default: the optional value to return if lookup failed; returns None if not set
+    Returns:
+      The first DNS Name of the OLDEST VPC endpoint found in the given VPC for the given service
+    """
+    vpc_name, service_name = lookup.split("/")
+    vpc_id = self.ec2_vpc_vpc_id(vpc_name)
+    if vpc_id is None:
+      return default
+
+    vpc_endpoints = EFAwsResolver.__CLIENTS["ec2"].describe_vpc_endpoints(Filters=[
+      {"Name": "vpc-id", "Values":[vpc_id]},
+      {"Name": "service-name", "Values":[service_name]}
+    ])
+    if len(vpc_endpoints.get("VpcEndpoints")) < 1:
+      return default
+
+    oldest = None
+    for vpce in vpc_endpoints.get("VpcEndpoints"):
+      if oldest is None or vpce["CreationTimestamp"] < oldest["CreationTimestamp"]:
+        oldest = vpce
+
+    if len(oldest["DnsEntries"]) < 1:
+      return default
+    return oldest["DnsEntries"][0]["DnsName"]
+
   def ec2_vpc_vpn_gateway_id(self, lookup, default=None):
     """
     Args:
@@ -883,6 +931,10 @@ class EFAwsResolver(object):
       return self.ec2_vpc_endpoint_id(*kv[1:])
     elif kv[0] == "ec2:vpc-endpoint/vpc-endpoint-id/by-vpc-service":
       return self.ec2_vpc_endpoint_id_by_vpc_service(*kv[1:])
+    elif kv[0] == "ec2:vpc-endpoint/dns-name":
+      return self.ec2_vpc_endpoint_dns_name(*kv[1:])
+    elif kv[0] == "ec2:vpc-endpoint/dns-name/by-vpc-service":
+      return self.ec2_vpc_endpoint_dns_name_by_vpc_service(*kv[1:])
     elif kv[0] == "ec2:vpc/vpn-gateway-id":
       return self.ec2_vpc_vpn_gateway_id(*kv[1:])
     elif kv[0] == "ecr:repository/repository-uri":
