@@ -53,6 +53,8 @@ AWS_RESOLVER = None
 SUPPORTED_SERVICE_TYPES = [
   "aws_cloudtrail",
   "aws_ec2",
+  "aws_ecs",
+  "aws_ecs_http",
   "aws_fixture",
   "aws_lambda",
   "aws_role",
@@ -74,14 +76,18 @@ GLOBAL_SERVICE_TYPES = [
 SERVICE_TYPE_ROLE = {
   "aws_cloudtrail": "cloudtrail.amazonaws.com",
   "aws_ec2": "ec2.amazonaws.com",
+  "aws_ecs": ["ecs.amazonaws.com", "ecs-tasks.amazonaws.com"],
+  "aws_ecs_http": ["ecs.amazonaws.com", "ecs-tasks.amazonaws.com"],
   "aws_lambda": "lambda.amazonaws.com",
   "aws_role": None, # Bare role requires a custom assume role policy ("assume_role_policy": "name_of_policy")
-  "http_service": ["ec2.amazonaws.com", "ecs.amazonaws.com", "ecs-tasks.amazonaws.com"]
+  "http_service": "ec2.amazonaws.com"
 }
 
 # these service types get Security Groups
 SG_SERVICE_TYPES = [
   "aws_ec2",
+  "aws_ecs",
+  "aws_ecs_http",
   "aws_lambda",
   "aws_security_group",
   "http_service"
@@ -90,12 +96,16 @@ SG_SERVICE_TYPES = [
 # these service types get instance profiles (they have EC2 instances)
 INSTANCE_PROFILE_SERVICE_TYPES = [
   "aws_ec2",
+  "aws_ecs",
+  "aws_ecs_http",
   "http_service"
 ]
 
 # these service types get KMS Keys
 KMS_SERVICE_TYPES = [
   "aws_ec2",
+  "aws_ecs",
+  "aws_ecs_http",
   "aws_fixture",
   "aws_lambda",
   "http_service"
@@ -212,7 +222,8 @@ def conditionally_create_security_groups(env, service_name, service_type):
   Args:
     env: the environment the SG will be created in
     service_name: name of the service in service registry
-    service_type: service registry service type: 'aws_ec2', 'aws_lambda', 'aws_security_group', or 'http_service'
+    service_type: service registry service type: 'aws_ec2', 'aws_ecs', 'aws_ecs_http',
+                                 'aws_lambda', 'aws_security_group', or 'http_service'
   """
   if service_type not in SG_SERVICE_TYPES:
     print_if_verbose("not eligible for security group(s); service type: {}".format(service_type))
@@ -221,6 +232,8 @@ def conditionally_create_security_groups(env, service_name, service_type):
   target_name = "{}-{}".format(env, service_name)
   if service_type == "aws_ec2":
     sg_names = ["{}-ec2".format(target_name)]
+  elif service_type == "aws_ecs":
+    sg_names = ["{}-ecs".format(target_name)]
   elif service_type == "aws_lambda":
     sg_names = ["{}-lambda".format(target_name)]
   elif service_type == "http_service":
@@ -228,6 +241,11 @@ def conditionally_create_security_groups(env, service_name, service_type):
       "{}-ec2".format(target_name),
       "{}-elb".format(target_name)
     ]
+  elif service_type == "aws_ecs_http":
+    sg_names = [
+      "{}-ecs".format(target_name),
+      "{}-elb".format(target_name)
+    ]
   elif service_type == "aws_security_group":
     sg_names = [target_name]
   else:
@@ -465,7 +483,8 @@ def conditionally_create_kms_key(role_name, service_type):
   Create KMS Master Key for encryption/decryption of sensitive values in cf templates and latebind configs
   Args:
       role_name: name of the role that kms key is being created for; it will be given decrypt privileges.
-      service_type: service registry service type: 'aws_ec2', 'aws_fixture', 'aws_lambda', or 'http_service'
+      service_type: service registry service type: 'aws_ec2', 'aws_ecs', 'aws_ecs_http', 'aws_fixture',
+                                                   'aws_lambda', or 'http_service'
   """
   if service_type not in KMS_SERVICE_TYPES:
     print_if_verbose("not eligible for kms; service_type: {} is not valid for kms".format(service_type))
@@ -565,7 +584,7 @@ def conditionally_create_kms_key(role_name, service_type):
       create_key_failures = 0
       while create_key_failures <= 5:
         try:
-          new_kms_key = CLIENTS["kms"].create_key(
+          kms_key = CLIENTS["kms"].create_key(
             Policy=json.dumps(kms_key_policy, indent=4),
             Description='Master Key for {}'.format(role_name)
           )
@@ -584,13 +603,16 @@ def conditionally_create_kms_key(role_name, service_type):
       try:
         CLIENTS["kms"].create_alias(
           AliasName='alias/{}'.format(key_alias),
-          TargetKeyId=new_kms_key['KeyMetadata']['KeyId']
+          TargetKeyId=kms_key['KeyMetadata']['KeyId']
         )
       except ClientError as error:
         fail("Exception creating alias for kms key: {} {}".format(role_name, error))
   else:
     print_if_verbose("KMS key already exists: {}".format(key_alias))
 
+  # Enable KMS key rotation
+  CLIENTS["kms"].enable_key_rotation(KeyId=kms_key["KeyMetadata"]["KeyId"])
+
 
 def create_newrelic_alerts():
   """
